@@ -1,6 +1,7 @@
 """
 Module contains models for MQTT communication with FIWARE's IoT-Agents.
 """
+
 from aenum import Enum
 
 
@@ -8,9 +9,10 @@ class IoTAMQTTMessageType(str, Enum):
     """
     Options for mqtt message type
     """
-    _init_ = 'value __doc__'
+
+    _init_ = "value __doc__"
     CMD = "cmd", "Command"
     CMDEXE = "cmdexe", "Command acknowledgement"
-    MULTI = "multi",  "Multi measurement"
+    MULTI = "multi", "Multi measurement"
     SINGLE = "single", "Single measurement"
-    CONFIG = "configuration", "Configuration message"
\ No newline at end of file
+    CONFIG = "configuration", "Configuration message"
